@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 
-'''
+"""
 This module implements functions to perform various useful operations on
 entries, such as grouping entries by structure.
-'''
+"""
 
 from __future__ import division
 
@@ -19,9 +19,9 @@ import json
 import datetime
 import collections
 
-from pymatgen.symmetry.finder import SymmetryFinder
 from pymatgen.core.structure_modifier import StructureEditor
-from pymatgen.analysis.structure_fitter import StructureFitter
+from pymatgen.analysis.structure_matcher import StructureMatcher, \
+    SpeciesComparator
 from pymatgen.serializers.json_coders import PMGJSONEncoder, PMGJSONDecoder
 
 logger = logging.getLogger(__name__)
@@ -37,8 +37,8 @@ def _get_host(structure, species_to_remove):
 
 
 def _perform_grouping(args):
-    (entries_json, hosts_json, anonymized, symmetry_tol, fitting_accuracy,
-     groups) = args
+    (entries_json, hosts_json, ltol, stol, angle_tol,
+     primitive_cell, scale, comparator, groups) = args
     entries = json.loads(entries_json, cls=PMGJSONDecoder)
     hosts = json.loads(hosts_json, cls=PMGJSONDecoder)
     unmatched = zip(entries, hosts)
@@ -48,33 +48,28 @@ def _perform_grouping(args):
             "Reference tid = {}, formula = {}".format(unmatched[0][0].entry_id,
                                                       ref_host.formula)
         )
-        ref_formula = ref_host.composition.anonymized_formula if anonymized \
-            else ref_host.composition.reduced_formula
+        ref_formula = ref_host.composition.reduced_formula
         logger.info("Reference host = {}".format(ref_formula))
         matches = [unmatched[0]]
         for i in xrange(1, len(unmatched)):
             test_host = unmatched[i][1]
             logger.info("Testing tid = {}, formula = {}"
                          .format(unmatched[i][0].entry_id, test_host.formula))
-            test_formula = test_host.composition.anonymized_formula \
-                if anonymized else test_host.composition.reduced_formula
+            test_formula = test_host.composition.reduced_formula
             logger.info("Test host = {}".format(test_formula))
-            if test_formula == ref_formula:
-                fitter = StructureFitter(ref_host, test_host,
-                                         anonymized=anonymized,
-                                         symmetry_tol=symmetry_tol,
-                                         fitting_accuracy=fitting_accuracy)
-                if fitter.fit_found:
-                    logger.info("Fit found")
-                    matches.append(unmatched[i])
+            m = StructureMatcher(comparator=comparator)
+            if m.fit(ref_host, test_host):
+                logger.info("Fit found")
+                matches.append(unmatched[i])
         groups.append(json.dumps([m[0] for m in matches], cls=PMGJSONEncoder))
         unmatched = filter(lambda x: x not in matches, unmatched)
         logger.info("{} unmatched remaining".format(len(unmatched)))
 
 
 def group_entries_by_structure(entries, species_to_remove=None,
-                               anonymized=False, symmetry_tol=0,
-                               fitting_accuracy=StructureFitter.FAST_FIT,
+                               ltol=0.2, stol=.4, angle_tol=5,
+                               primitive_cell=True, scale=True,
+                               comparator=SpeciesComparator(),
                                ncpus=None):
     """
     Given a sequence of ComputedStructureEntries, use structure fitter to group
@@ -87,11 +82,23 @@ def group_entries_by_structure(entries, species_to_remove=None,
             Sometimes you want to compare a host framework (e.g., in Li-ion
             battery analysis). This allows you to specify species to remove
             before structural comparison.
-        anonymized:
-            Allow anonymized fitting.
-        fitting_accuracy:
-            The fitting accuracy to use for StructureFitter. Defaults to
-            FAST_FIT.
+        ltol:
+            Fractional length tolerance. Default is 0.2
+        stol:
+            Site tolerance in Angstrom. Default is 0.4 Angstrom
+        angle_tol:
+            Angle tolerance in degrees. Default is 5 degrees.
+        primitive_cell:
+            If true: input structures will be reduced to primitive cells
+            prior to matching. Defaults to True.
+        scale:
+            Input structures are scaled to equivalent volume if true;
+            For exact matching, set to False.
+        comparator:
+            A comparator object implementing an equals method that declares
+            declaring equivalency of sites.
+            Default is SpeciesComparator, which implies rigid species
+            mapping.
         ncpus:
             Number of cpus to use. Use of multiple cpus can greatly improve
             fitting speed. Default of None means serial processing.
@@ -108,13 +115,8 @@ def group_entries_by_structure(entries, species_to_remove=None,
     if ncpus:
         symm_entries = collections.defaultdict(list)
         for entry, host in entries_host:
-            key = [host.composition.anonymized_formula
-                   if anonymized
-                   else host.composition.reduced_formula]
-            if symmetry_tol:
-                finder = SymmetryFinder(host, symmetry_tol)
-                key.append(finder.get_spacegroup_number())
-            symm_entries[tuple(key)].append((entry, host))
+            symm_entries[comparator.get_structure_hash(host)].append((entry,
+                                                                      host))
         import multiprocessing as mp
         logging.info("Using {} cpus".format(ncpus))
         manager = mp.Manager()
@@ -124,16 +126,16 @@ def group_entries_by_structure(entries, species_to_remove=None,
         p.map(_perform_grouping,
               [(json.dumps([e[0] for e in eh], cls=PMGJSONEncoder),
                 json.dumps([e[1] for e in eh], cls=PMGJSONEncoder),
-                anonymized,
-                symmetry_tol, fitting_accuracy, groups)
+                ltol, stol, angle_tol, primitive_cell, scale,
+                comparator, groups)
                for eh in symm_entries.values()])
     else:
         groups = []
         hosts = [host for entry, host in entries_host]
         _perform_grouping((json.dumps(entries, cls=PMGJSONEncoder),
                            json.dumps(hosts, cls=PMGJSONEncoder),
-                           anonymized,
-                           symmetry_tol, fitting_accuracy, groups))
+                           ltol, stol, angle_tol, primitive_cell, scale,
+                           comparator, groups))
     entry_groups = []
     for g in groups:
         entry_groups.append(json.loads(g, cls=PMGJSONDecoder))
